Budget
======


Budget is your own personal financial assistant. With Budget, you can record income and expenses into separate categories. Set a limit on each individual category and notifications when you are approaching your limits. Budget can also help predict your financial future. Plan your long term financial health with monthly and yearly projections. Plan your immediate future with the daily and weekly projections.


<a href="http://www.mthx.org/projects/budget">Project Home Page</a>
